
//////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
//  Ferdinand Görtz                                 03.05.2021                                           geändert 24.08.2022        //
//  Mit einem Arduino Nano wird mit einem Taster der Ablauf gestartet. Der auf einem JQ6500 Modul gepeicherte Sound wird gestartet. //
//  Das Relais für die Viessmann eMotion Figur wird umgeschaltet.  Nach Ablauf der Einschaltzeit "Saege" wird die Kettensäge        //
//  wieder ausgeschaltet.                                                                                                           //
//  Der Servo und damit der Baum dreht sich erst langsam, dann immer schneller. Wenn der Baum den Boden berührt, wippt dieser noch  //
//  nach. Damit endet auch der Sound.                                                                                               //
//  Nach einer Ruhepause "pause" von 20 Sekunden kann der Ablauf erneut gestartet werden.                                           //  
//////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////

#include <Arduino.h>   
#include <Servo.h>           // Die Servobibliothek wird aufgerufen. Sie wird benötigt, damit die Ansteuerung des Servos vereinfacht wird.
#include <SoftwareSerial.h>  // Diese Bibliothek wird benötigt, damit die Ansteuerung vereinfacht wird.
#include <JQ6500_Serial.h>   // Diese Bibliothek wird benötigt, damit die Ansteuerung vereinfacht wird.
JQ6500_Serial mp3(6,7);      // Arduino Pin 5 ist mit TX am JQ6500 verbunden
                             // Arduino Pin 6 ist mit einem Ende eines 1 kOhm Widerstandes verbunden,
                             // das andere Ende des 1 kOhm Widerstandes ist mit RX am JQ6500 verbunden
Servo servobaum;             // Erstellt fuer das Programm einen Servo mit dem Namen "servobaum"

int taster   = A2;         // Das Wort "taster" steht jetzt für den Wert A2.
int LEDtaster = 11;        // Das Wort "LEDtaster" steht jetzt für den Wert 11.
int servo    = 2;          // Das Wort "servo" steht jetzt für den Wert 2.
int relais   = 3;          // Das Wort "relais" steht jetzt für den Wert 3.
int kontrollLED = 12;      // Das Wort "kontrollLED" steht jetzt für den Wert 12.

int Saege = 14200;         // Zeit für eingeschaltete Säge
int pause = 20000;         // Pause vor dem erneuten Starten der Aktion.  
int tasterstatus = HIGH;   // Das Wort "tasterstatus" steht jetzt zunachst für den Wert HIGH gesetzt. Später wird unter dieser Variable gespeichert, ob der Taster gedrückt ist oder nicht.
int pos=0;


void setup()               //Hier beginnt das Setup.
{
  pinMode(LEDtaster, OUTPUT);     // Der Pin mit der LED (Pin 5) ist jetzt ein Ausgang.
  pinMode(taster, INPUT_PULLUP);  // Der Pin mit dem Taster (Pin 3) ist jetzt ein Eingangmit dem Potential HIGH.
  pinMode(relais, OUTPUT);        // Der Pin mit dem Relais (Pin 7) ist jetzt ein Ausgang.
  digitalWrite(relais, HIGH);      // danach soll das Relais umschalten.
  pinMode(servo, OUTPUT);         // Der Pin mit dem Servo (Pin 6) ist jetzt ein Ausgang.
  servobaum.attach(servo);        // Das Setup enthält die Information, dass das Servo an der Steuerleitung (gelb) mit Pin 6 verbunden wird.
  mp3.begin(9600);
  mp3.reset();                     // Initialisiert das SD-Modul, Sound.
  mp3.setVolume (20);              // Lautstärke auf den Wert 20
  mp3.setLoopMode(MP3_LOOP_NONE);  // keine laufende Wiederholung des Sounds
}

void loop()
{                                     // Mit dieser Klammer wird der Loop-Teil geöffnet.
  tasterstatus = digitalRead(taster); // Hier wird der Pin3 ausgelesen (Befehl:digitalRead).
                                      // Das Ergebnis wird unter der Variable "tasterstatus" mit dem Wert "HIGH" für 5Volt oder "LOW" für 0Volt gespeichert.
  if (tasterstatus == LOW)            // Verarbeitung: Wenn der Taster gedrückt ist
  {                                   // Programmabschnitt des IF-Befehls öffnen.
    digitalWrite(LEDtaster, HIGH);    // dann soll die LED am Taster leuchten
    digitalWrite(kontrollLED, HIGH);  // dann soll die LED auf dem Tastenfeld leuchten 
    digitalWrite(relais, LOW);        // An dieser Stelle würde das Relais eingeschaltet
    mp3.playFileByIndexNumber(1);     // Spielt synchron ein audio file.
    delay (Saege);                    // und zwar für die Zeit "Saege" = 16 Sekunden (16000 Millisekunden).
    digitalWrite(relais, HIGH);        // danach soll das Relais umschalten.

      for (pos = 97; pos >= 93; pos -= 1)   // fährt von 97 Grad bis 93 Grad 
                                            // Falls der Baum zu Beginn nicht senkrecht steht, kann hier korrigiert werden
                                            // in Stufen von 1 Grad
        { servobaum.write(pos);             // sagt dem Servo zur Position der Variablen 'pos'zu drehen
          delay(600);                       // wartet 200ms damit der Servo seine Position erreicht               
        }

      for (pos = 92; pos >= 88; pos -= 1)  // fährt von 92 Grad bis 88 Grad
                                           // in Stufen von 1 Grad
       { servobaum.write(pos);             // sagt dem Servo zur Position der Variablen 'pos' zu drehen
         delay(400);                       // wartet 150 ms damit der Servo seine Position erreicht
       }


      for (pos = 87; pos >= 79; pos -= 1) // fährt von 87 Grad bis 79 Grad
                                          // in Stufen von 1 Grad
        { servobaum.write(pos);           // sagt dem Servo zur Position der Variablen 'pos' zu drehen
          delay(90);                      // wartet 80ms damit der Servo seine Position erreicht
        }


      for (pos = 78; pos >= 12; pos -= 1) // fährt von 78 Grad bis 12 Grad
                                          // in Stufen von 1 Grad
        { servobaum.write(pos);           // sagt dem Servo zur Position der Variablen 'pos' zu drehen
          delay(30);                      // wartet 50ms damit der Servo seine Position erreicht
        }


      for (pos = 11; pos <= 20; pos += 1) // fährt von 11 Grad bis 20 Grad zurück (wippen)
                                          // in Stufen von 1 Grad
        { servobaum.write(pos);           // sagt dem Servo zur Position der Variablen 'pos' zu drehen
          delay(60);                      // wartet 60ms damit der Servo seine Position erreicht
        }


      for (pos = 19; pos >= 12; pos -= 1) // fährt von 19 Grad bis 12 Grad
                                          // in Schritten von 1 Grad
        { servobaum.write(pos);           // sagt dem Servo zur Position der Variablen 'pos' zu drehen
          delay(150);                     // wartet 150ms damit der Servo seine Position erreicht
        }


       mp3.pause();                         // Stoppt die aktuelle Audio Datei. 
       delay(pause);                        // Wartezeit 20 Sekunde

      for (pos = 12; pos <= 97; pos += 1)  // fährt von 12 Grad bis 97 Grad zurück (Grundstellung)in Stufen von 1 Grad
        { servobaum.write(pos);            // sagt dem Servo zur Position der Variablen 'pos' zu drehen
          delay(10);                       // wartet 10ms damit der Servo seine Position erreicht
        }

 
     digitalWrite(LEDtaster, LOW);    // dann soll die LED am Taster aus sein
     digitalWrite(kontrollLED, LOW);  // ...soll die LED auf der Platine aus sein.
  }                                   // Programmabschnitt des IF-Befehls schliessen.
    else                              // ...ansonsten...
  {                                   // Programmabschnitt des else-Befehls oeffnen. Stellt sicher das auch bei Neustart alles ausgeschaltet ist.
    digitalWrite(LEDtaster, LOW);     // ...soll die LED am Taster aus sein.
    digitalWrite(kontrollLED, LOW);   // ...soll die LED auf der Platine aus sein.

  }                                   // Programmabschnitt des else-Befehls schliessen.
}                                     // Mit dieser letzten Klammer wird der Loop-Teil geschlossen.
